@@ -6,7 +6,7 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
          use.se=TRUE, outpdf=NULL, outfile=NULL) {
     UseMethod("calSGCED")
 } ###
-### 2018.04.26. 
+### 2018.05.18. 
 calSGCED.default <-
 function(obj_analyseBIN, SGCpars, model, origin, avgDev, 
          method="SGC", SAR.Cycle="N", errMethod="sp", Tn.above.3BG=TRUE, 
@@ -129,16 +129,29 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
             ###
             select_index <- which(all_value==1L)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SGC ED if [Tn.above.3BG] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 "Rejection criterion: Tn below 3 sigma BG")
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SGC ED if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character,
+                          "Total number of rejected aliquots (grains)",
+                          "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
             LnTn.curve <- LnTn.curve[select_index]
@@ -164,16 +177,29 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
                 select_index <- which(all_value+sigma*all_se_value>TnBG.ratio.low)
             } # end if.
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SGC ED if [TnBG.ratio.low] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: ratio of Tn to BG below ", TnBG.ratio.low, sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SGC ED if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character,
+                          "Total number of rejected aliquots (grains)",
+                          "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
             LnTn.curve <- LnTn.curve[select_index]
@@ -194,16 +220,29 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
             ###
             select_index <- which(abs(all_value)<rseTn.up)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SGC ED if [rseTn.up] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: RSE of Tn exceeds ", rseTn.up, "%", sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SGC ED if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character,
+                          "Total number of rejected aliquots (grains)",
+                          "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
             LnTn.curve <- LnTn.curve[select_index]
@@ -229,15 +268,28 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
                 select_index <- which(all_value+sigma*all_se_value>FR.low)
             } # end if.
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SGC ED if [FR.low] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: fast ratio of Tn below ", FR.low, sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
+            ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SGC ED if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character,
+                          "Total number of rejected aliquots (grains)",
+                          "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
             ### 
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
@@ -752,16 +804,29 @@ function(obj_analyseBIN, SGCpars, model, origin, avgDev,
             ###
             select_index <- which(abs(all_value)<rseED.up)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SGC ED if [rseED.up] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(SGCED.table) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: RSE of ED exceeds ", rseED.up, "%",sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SGC ED if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character,
+                          "Total number of rejected aliquots (grains)",
+                          "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             SGCED.table <- SGCED.table[select_index,,drop=FALSE]
             rseED_reject <- apply(agID[-select_index,,drop=FALSE], MARGIN=1L, NPG)
             agID <- agID[select_index,,drop=FALSE]
