@@ -7,7 +7,7 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
          use.se=TRUE, norm.dose=NULL, outpdf=NULL, outfile=NULL) {
     UseMethod("pickSARdata")
 } #
-### 2018.04.26.
+### 2018.05.18.
 pickSARdata.default <-
 function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE, 
          nofit.rgd=NULL, Tn.above.3BG=TRUE, TnBG.ratio.low=NULL, rseTn.up=NULL,
@@ -101,16 +101,29 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             ###
             select_index <- which(all_value==1L)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [Tn.above.3BG] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 "Rejection criterion: Tn below 3 sigma BG")
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
             LnTn.curve <- LnTn.curve[select_index]
@@ -137,16 +150,29 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                 select_index <- which(all_value+sigma*all_se_value>TnBG.ratio.low)
             } # end if.
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [TnBG.ratio.low] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: ratio of Tn to BG below ", TnBG.ratio.low, sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
             LnTn.curve <- LnTn.curve[select_index]
@@ -168,15 +194,28 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             ###
             select_index <- which(abs(all_value)<rseTn.up)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [rseTn.up] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: RSE of Tn exceeds ", rseTn.up, "%", sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
+            ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
             ### 
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
@@ -204,15 +243,28 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                 select_index <- which(all_value+sigma*all_se_value>FR.low)
             } # end if.
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [FR.low] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(criteria) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: fast ratio of Tn below ", FR.low, sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
+            ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
             ### 
             criteria <- criteria[select_index,,drop=FALSE]
             Tn <- Tn[select_index,,drop=FALSE]
@@ -291,10 +343,6 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                                   is.na(all_value))
         } # end if.
         ###
-        if (length(select_index)==0L) {
-            stop("Error: no acceptable SAR data if [rcy1.range] is applied!")
-        } # end if.
-        ###
         reject_N <- nrow(RcyRcp_mat) - length(select_index)
         ###
         action_character <- c(action_character, 
@@ -302,6 +350,23 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             rcy1.range[1L], ",",rcy1.range[2L],"]", sep=""))
         step_reject_N <- c(step_reject_N, reject_N)
         ###
+        if (length(select_index)==0L) {
+            ###
+            cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+            ###
+            action_character <- c(action_character, 
+                "Total number of rejected aliquots (grains)",
+                "Total number of accepted aliquots (grains)")
+            ###
+            step_reject_N <- c(step_reject_N, nag, 0L)
+            ###
+            summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+            ###
+            print(summary_info)
+            ###
+            return(invisible(summary_info))
+        } # end if.
+        ###
         RcyRcp_mat <- RcyRcp_mat[select_index,,drop=FALSE]
         ###
         if (!is.null(criteria)) criteria <- criteria[select_index,,drop=FALSE]
@@ -334,10 +399,6 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                                   is.na(all_value))
         } # end if.
         ###
-        if (length(select_index)==0L) {
-            stop("Error: no acceptable SAR data if [rcy2.range] is applied!")
-        } # end if.
-        ###
         reject_N <- nrow(RcyRcp_mat) - length(select_index)
         ###
         action_character <- c(action_character, 
@@ -345,6 +406,23 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             rcy2.range[1L], ",",rcy2.range[2L],"]", sep=""))
         step_reject_N <- c(step_reject_N, reject_N)
         ###
+        if (length(select_index)==0L) {
+            ###
+            cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+            ###
+            action_character <- c(action_character, 
+                "Total number of rejected aliquots (grains)",
+                "Total number of accepted aliquots (grains)")
+            ###
+            step_reject_N <- c(step_reject_N, nag, 0L)
+            ###
+            summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+            ###
+            print(summary_info)
+            ###
+            return(invisible(summary_info))
+        } # end if.
+        ###
         RcyRcp_mat <- RcyRcp_mat[select_index,,drop=FALSE]
         ###
         if (!is.null(criteria)) criteria <- criteria[select_index,,drop=FALSE]
@@ -377,10 +455,6 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                                   is.na(all_value))
         } # end if.
         ###
-        if (length(select_index)==0L) {
-            stop("Error: no acceptable SAR data if [rcy3.range] is applied!")
-        } # end if.
-        ###
         reject_N <- nrow(RcyRcp_mat) - length(select_index)
         ###
         action_character <- c(action_character, 
@@ -388,6 +462,23 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             rcy3.range[1L], ",",rcy3.range[2L],"]", sep=""))
         step_reject_N <- c(step_reject_N, reject_N)
         ###
+        if (length(select_index)==0L) {
+            ###
+            cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+            ###
+            action_character <- c(action_character, 
+                "Total number of rejected aliquots (grains)",
+                "Total number of accepted aliquots (grains)")
+            ###
+            step_reject_N <- c(step_reject_N, nag, 0L)
+            ###
+            summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+            ###
+            print(summary_info)
+            ###
+            return(invisible(summary_info))
+        } # end if.
+        ###
         RcyRcp_mat <- RcyRcp_mat[select_index,,drop=FALSE]
         ###
         if (!is.null(criteria)) criteria <- criteria[select_index,,drop=FALSE]
@@ -420,16 +511,29 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                                   is.na(all_value))
         } # end if.
         ###
-        if (length(select_index)==0L) {
-            stop("Error: no acceptable SAR data if [rcp1.up] is applied!")
-        } # end if.
-        ###
         reject_N <- nrow(RcyRcp_mat) - length(select_index)
         ###
         action_character <- c(action_character, 
             paste("Rejection criterion: recuperation 1 exceeds ", rcp1.up, "%",sep=""))
         step_reject_N <- c(step_reject_N, reject_N)
         ###
+        if (length(select_index)==0L) {
+            ###
+            cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+            ###
+            action_character <- c(action_character, 
+                "Total number of rejected aliquots (grains)",
+                "Total number of accepted aliquots (grains)")
+            ###
+            step_reject_N <- c(step_reject_N, nag, 0L)
+            ###
+            summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+            ###
+            print(summary_info)
+            ###
+            return(invisible(summary_info))
+        } # end if.
+        ###
         RcyRcp_mat <- RcyRcp_mat[select_index,,drop=FALSE]
         ###
         if (!is.null(criteria)) criteria <- criteria[select_index,,drop=FALSE]
@@ -461,16 +565,29 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
                                   is.na(all_value))
         } # end if.
         ###
-        if (length(select_index)==0L) {
-            stop("Error: no acceptable SAR data if [rcp2.up] is applied!")
-        } # end if.
-        ###
         reject_N <- nrow(RcyRcp_mat) - length(select_index)
         ###
         action_character <- c(action_character, 
             paste("Rejection criterion: recuperation 2 exceeds ", rcp2.up, "%",sep=""))
         step_reject_N <- c(step_reject_N, reject_N)
         ###
+        if (length(select_index)==0L) {
+            ###
+            cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+            ###
+            action_character <- c(action_character, 
+                "Total number of rejected aliquots (grains)",
+                "Total number of accepted aliquots (grains)")
+            ###
+            step_reject_N <- c(step_reject_N, nag, 0L)
+            ###
+            summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+            ###
+            print(summary_info)
+            ###
+            return(invisible(summary_info))
+        } # end if.
+        ###
         RcyRcp_mat <- RcyRcp_mat[select_index,,drop=FALSE]
         ###
         if (!is.null(criteria)) criteria <- criteria[select_index,,drop=FALSE]
@@ -741,16 +858,29 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             ###
             select_index <- which(abs(all_value)<fom.up)
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [fom.up] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(SARdata.table) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: FOM of growth curve exceeds ", fom.up, "%",sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                ###
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             SARdata.table <- SARdata.table[select_index,,drop=FALSE]
             fom_reject <- apply(agID[-select_index,,drop=FALSE], MARGIN=1L, NPG)
             agID <- agID[select_index,,drop=FALSE]
@@ -769,16 +899,28 @@ function(obj_analyseBIN, model="gok", origin=FALSE, weight=TRUE, trial=TRUE,
             ###
             select_index <- which(abs(all_value)<rcs.up | is.na(all_value))
             ###
-            if (length(select_index)==0L) {
-                stop("Error: no acceptable SAR data if [rcs.up] is applied!")
-            } # end if.
-            ###
             reject_N <- nrow(SARdata.table) - length(select_index)
             ###
             action_character <- c(action_character, 
                 paste("Rejection criterion: RCS of growth curve exceeds ", rcs.up, sep=""))
             step_reject_N <- c(step_reject_N, reject_N)
             ###
+            if (length(select_index)==0L) {
+                cat("NOTE: no acceptable SAR data if the specified rejection criteria are applied!\n")
+                ###
+                action_character <- c(action_character, 
+                    "Total number of rejected aliquots (grains)",
+                    "Total number of accepted aliquots (grains)")
+                ###
+                step_reject_N <- c(step_reject_N, nag, 0L)
+                ###
+                summary_info <- data.frame("Description"=action_character, "N"=step_reject_N)
+                ###
+                print(summary_info)
+                ###
+                return(invisible(summary_info))
+            } # end if.
+            ###
             SARdata.table <- SARdata.table[select_index,,drop=FALSE]
             rcs_reject <- apply(agID[-select_index,,drop=FALSE], MARGIN=1L, NPG)
             agID <- agID[select_index,,drop=FALSE]
